pub enum Op<D>where
D: Device,{
Unary(UnaryOp, LazyBuffer<D>),
Binary(BinaryOp, LazyBuffer<D>, LazyBuffer<D>),
MatMul(LazyBuffer<D>, LazyBuffer<D>, (usize, usize, usize, usize), bool),
Reduce(ReduceOp, LazyBuffer<D>, usize),
Const(Const),
Value,
Layout(LayoutOp, LazyBuffer<D>),
Reshape(LazyBuffer<D>),
Custom {
f: CustomF<<D as Device>::Slice>,
args: Vec<LazyBuffer<D>>,
},
CustomIp {
f: CustomF<<D as Device>::Slice>,
args: Vec<LazyBuffer<D>>,
src: LazyBuffer<D>,
},
Ssa {
ssa: Kernel,
args: Vec<LazyBuffer<D>>,
},
Set {
values: LazyBuffer<D>,
src: LazyBuffer<D>,
dst_layout: Layout,
},
}Variants
Unary(UnaryOp, LazyBuffer<D>)
Binary(BinaryOp, LazyBuffer<D>, LazyBuffer<D>)
MatMul(LazyBuffer<D>, LazyBuffer<D>, (usize, usize, usize, usize), bool)
Reduce(ReduceOp, LazyBuffer<D>, usize)
Const(Const)
Value
Values are leafs of the op DAG, holding values that do not depend on other values.
Layout(LayoutOp, LazyBuffer<D>)
Reshape(LazyBuffer<D>)
Custom
CustomIp
In-place variant of the custom op.
Ssa
Custom op based on some SSA code.
Set
Set the data from src using data from values. The LazyBuffer is shared between self and src.