pub struct ThreadBlock {
pub dim: usize,
pub block_dim: usize,
}Fields
dim: usizedim is the axis along which worker processes are split.
block_dim: usizeblock_dim is the number of worker processes on the specified dim.