pub struct Shape(/* private fields */);Implementations
Sourceimpl Shape
impl Shape
pub fn num_elements(&self) -> usize
pub fn from_dims(dims: &[usize]) -> Shape
Sourcepub fn rank(&self) -> usize
pub fn rank(&self) -> usize
The rank is the number of dimensions, 0 for a scalar value, 1 for a vector, etc.
pub fn into_dims(self) -> Vec<usize>
Sourcepub fn elem_count(&self) -> usize
pub fn elem_count(&self) -> usize
The total number of elements, this is the product of all dimension sizes.
Sourcepub fn stride_contiguous(&self) -> Vec<usize>
pub fn stride_contiguous(&self) -> Vec<usize>
The strides given in number of elements for a contiguous n-dimensional arrays using this shape.
Sourcepub fn is_contiguous(&self, stride: &[usize]) -> bool
pub fn is_contiguous(&self, stride: &[usize]) -> bool
Returns true if the strides are C contiguous (aka row major).
Sourcepub fn is_fortran_contiguous(&self, stride: &[usize]) -> bool
pub fn is_fortran_contiguous(&self, stride: &[usize]) -> bool
Returns true if the strides are Fortran contiguous (aka column major).